@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2013
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -21,13 +21,13 @@
 
 #define APP_NAME		"Tickr"
 #define APP_CMD			"tickr"
-#define APP_VERSION_NUMBER	"0.6.2"
+#define APP_VERSION_NUMBER	"0.6.3"
 #define WEBSITE_URL		"http://www.newsrssticker.com"
 #define SUPPORT_URL		WEBSITE_URL"/help.php"
 #define DOWNLOAD_URL		WEBSITE_URL"/download.php"
 #define SUPPORT_EMAIL_ADDR	"manu@newsrssticker.com"
 #define CHECK4UPDATES_URL	WEBSITE_URL"/app_version_visible.php"
-#define CHECK4UPDATES_ID_STR	"LSVN="	/* Stands for 'Last Stable Version Number =' */
+#define CHECK4UPDATES_ID_STR	"LSVN="	/* Stands for 'Last Stable Version Number = ' */
 
 #define _GNU_SOURCE
 #define _ISOC99_SOURCE
@@ -161,7 +161,7 @@
 #endif
 #define CONFIG_FILE		APP_CMD"-conf"
 #define URL_LIST_FILE		APP_CMD"-url-list"
-#define RESOURCE_DUMP		APP_CMD"-resrc-dump"
+#define RESOURCE_DUMP		APP_CMD"-resrc-dump.xml"
 #define XML_DUMP		APP_CMD"-xml-dump"
 #define XML_DUMP_EXTRA		APP_CMD"-xml-dump-extra"
 #define TMP1			"tmp1"
@@ -240,7 +240,7 @@
 #define CLOCK			'n'
 #define CFONTNAME		FONTNAME
 #define CFONTSIZE		"12"
-#define CFGCOLOR		"#aeaeaeff"	/* White but darker than text*/
+#define CFGCOLOR		"#aeaeaeff"	/* White but darker than text */
 #define CBGCOLOR		BGCOLOR
 #define DISABLEPOPUPS		'n'
 #define PAUSEONMOUSEOVER	'y'
@@ -275,7 +275,7 @@ typedef enum {
 
 typedef enum {
 	RSS_FORMAT_UNDETERMINED,
-	RSS_1_0,
+	RSS_1_0,	/* should use RDF or RSS_RDF instead ? */
 	RSS_2_0,
 	RSS_ATOM
 } _rss_format;
@@ -534,7 +534,7 @@ void		check_main_win_always_on_top();
 char		*get_feed_extra_info(int);
 /*gboolean	params_have_been_changed(Params *, int);*/
 gboolean	win_params_have_been_changed(Params *, int);
-gint		update_everything();
+void		update_pixmap_from_opened_stream();
 
 /* tickr_resource.c */
 int		build_feed_selection_from_feed_list();
