@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2013
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -272,7 +272,7 @@ static int add_feed_to_flnode_and_list_store(Resource *resrc, GtkListStore *list
  * Open a dialog with a list of urls to choose from and an url entry.
  *
  * Entry format in url list file:
- *	['*' (selected) or '-' (unselected) + (NEW VERSION) "000" (3 chars rank) + url [+ '>' + title] + '\n']
+ *	['*' (selected) or '-' (unselected) + "000" (3 chars rank) + url [+ '>' + title] + '\n']
  *
  * Entry max length = FILE_NAME_MAXLEN
  * See also:	(UN)SELECTED_URL_CHAR/STR and TITLE_TAG_CHAR/STR in tickr.h
@@ -539,7 +539,8 @@ void get_new_url(Resource *resrc)
 			build_feed_selection_from_feed_list();
 			if (IS_FLIST(get_feed_selection()) && response == GTK_RESPONSE_SELECTION)
 				first_feed();
-			f_list_free_all(flist_bak);
+			if (IS_FLIST(flist_bak))
+				f_list_free_all(flist_bak);
 		} else {
 			info_win("", "Invalid new feed list", INFO_ERROR, TRUE);
 			fprintf(STD_ERR, "Invalid new feed list\n");
