@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2013
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -151,9 +151,6 @@ int connect_with_url(sockt *sock, char *url)
 int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 {
 	sockt	sock;
-/*#ifdef G_OS_WIN32
-	gchar	*win32_filename;
-#endif*/
 	int	status, recv_status;
 	char	*response;
 	char	*new_url;
@@ -173,13 +170,7 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 		else
 			return RESOURCE_ERROR;
 
-/*#ifndef G_OS_WIN32*/
 		if (g_file_get_contents(url + i, &response, NULL, &error)) {
-/*#else
-		win32_filename = g_win32_locale_filename_from_utf8(url + i);
-		if (g_file_get_contents(win32_filename, &response, NULL, &error)) {
-			g_free(win32_filename);
-#endif*/
 			if ((j = format_quick_check(response, &i)) == OK) {
 				if (g_file_set_contents(file_name, response + i, -1, &error)) {
 					g_free(response);
@@ -198,9 +189,6 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 				return j;
 			}
 		} else {
-/*#ifdef G_OS_WIN32
-			g_free(win32_filename);
-#endif*/
 			if (error != NULL) {
 				warning(S_MOD, 1, error->message);
 				g_error_free(error);
