@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2013
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -422,7 +422,7 @@ int f_list_search(FList *some_node, const char *str)
  * Create new f_list.
  *
  * Entry format in url list file:
- *	['*' (selected) or '-' (unselected) + (NEW VERSION) "000" (3 chars rank) + url [+ '>' + title] + '\n']
+ *	['*' (selected) or '-' (unselected) + "000" (3 chars rank) + url [+ '>' + title] + '\n']
  *
  * Entry max length = FILE_NAME_MAXLEN
  * See also:	(UN)SELECTED_URL_CHAR/STR and TITLE_TAG_CHAR/STR in tickr.h
@@ -508,7 +508,7 @@ int f_list_load_from_file(FList **new_node, const char *file_name)
  * Use provided file_name if not NULL / default file name (URL_LIST_FILE) otherwise.
  *
  * Entry format in url list file:
- *	['*' (selected) or '-' (unselected) + (NEW VERSION) "000" (3 chars rank) + url [+ '>' + title] + '\n']
+ *	['*' (selected) or '-' (unselected) + "000" (3 chars rank) + url [+ '>' + title] + '\n']
  *
  * Entry max length = FILE_NAME_MAXLEN
  * See also:	(UN)SELECTED_URL_CHAR/STR and TITLE_TAG_CHAR/STR in tickr.h
