@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2013
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -295,8 +295,8 @@ static void about_win2()
 static void show_resource_info()
 {
 	GtkWidget	*dialog, *table, *label[7], *close_but;
-	char		tmp[256];
-	int		i;
+	char		tmp1[256], *tmp2, *tmp3;
+	int		i, j;
 
 	if (resrc->type != RESRC_URL && resrc->type != RESRC_FILE) {
 		info_win("Resource Properties", "\nNo information available\n", INFO_ERROR, FALSE);
@@ -328,16 +328,32 @@ static void show_resource_info()
 	label[0] = gtk_label_new("        ");
 	if (resrc->type == RESRC_URL) {
 		label[1] = gtk_label_new("Resource type:");
-		snprintf(tmp, 256, "%s Feed", resrc->format == RSS_2_0 ? "RSS 2.0" : \
+		snprintf(tmp1, 256, "%s Feed", resrc->format == RSS_2_0 ? "RSS 2.0" : \
 			(resrc->format == RSS_ATOM ? "Atom" : "RSS 1.0"));
-		label[2] = gtk_label_new(tmp);
+		label[2] = gtk_label_new(tmp1);
 
 		label[3] = gtk_label_new("Feed title:");
 		label[4] = gtk_label_new(resrc->feed_title);
 
 		label[5] = gtk_label_new("Feed URL:");
-		snprintf(tmp, 256, "<a href=\"%s\">%s</a>", resrc->id, resrc->id);
-		label[6] = gtk_label_new(tmp);
+		tmp2 = l_str_new("<a href=\"");
+		tmp3 = malloc2(sizeof(char) * FILE_NAME_MAXLEN * 2);
+		/* Need to replace all "&" with "&amp;" to use markup. */
+		for (i = 0, j = 0; resrc->id[i] != '\0' && j < (FILE_NAME_MAXLEN * 2) - 4; i++, j++)
+			if (resrc->id[i] != '&')
+				tmp3[j] = resrc->id[i];
+			else {
+				str_n_cpy(tmp3 + j, "&amp;", 5);
+				j += 4;
+			}
+		tmp3[j] = '\0';
+		tmp2 = l_str_cat(tmp2, tmp3);
+		tmp2 = l_str_cat(tmp2, "\">");
+		tmp2 = l_str_cat(tmp2, tmp3);
+		tmp2 = l_str_cat(tmp2, "</a>");
+		label[6] = gtk_label_new(tmp2);
+		l_str_free(tmp2);
+		free2(tmp3);
 		gtk_label_set_use_markup(GTK_LABEL(label[6]), TRUE);
 
 		for (i = 0; i < 7; i++)
@@ -884,10 +900,10 @@ gboolean win_params_have_been_changed(Params *new_prm, int n_required_runs)
  */
 static int compute_surface_and_win()
 {
-	char 		fname[FONT_NAME_MAXLEN + 1], fsize[FONT_SIZE_MAXLEN + 1];
-	char		cfname[FONT_NAME_MAXLEN + 1], cfsize[FONT_SIZE_MAXLEN + 1];
-	gint		height1, height2;
-	int		size, render_exit_status, i;
+	char 	fname[FONT_NAME_MAXLEN + 1], fsize[FONT_SIZE_MAXLEN + 1];
+	char	cfname[FONT_NAME_MAXLEN + 1], cfsize[FONT_SIZE_MAXLEN + 1];
+	gint	height1, height2;
+	int	size, render_exit_status, i;
 
 	/*
 	 * Compute font size from requested height if > 0
@@ -977,9 +993,6 @@ static int compute_surface_and_win()
 	env->surf_width = cairo_image_surface_get_width(env->c_surf);
 	env->surf_height = cairo_image_surface_get_height(env->c_surf);
 	env->drwa_height = (MIN(env->surf_height, env->screen_h));
-	/*
-	 * Window layout stuff - 'TICKR STEAL FOCUS' BUG SOMEWERE
-	 */
 	/* Win title */
 	gtk_window_set_title(GTK_WINDOW(env->win), get_win_title_text());
 	/* Whole window transparency */
@@ -1237,22 +1250,31 @@ static void print_license()
 	fprintf(STD_OUT, "%s\n", get_license_str2());
 }
 
-/* Reload resource as soon as scrolling has started to update all display params.
- * TODO: reset open stream to begining and recompute instead of reloading (which
- * is useless) -> must first make sure this doesn't break anything.
- */
-gint update_everything()
+/* Reset display params as soon as scrolling has started. */
+static gint update_everything()
 {
 	if (shift_counter > 4) {
-		if (env->selection_mode == MULTIPLE)
-			current_feed();
-		else
-			env->reload_rq = TRUE;
+		update_pixmap_from_opened_stream();
 		return FALSE;
 	} else
 		return TRUE;
 }
 
+/* Reset opened stream to begining and recompute pixmap, in order to
+ * update all display params.
+ * (Hmmm... we should find a more informative name.)
+ */
+void update_pixmap_from_opened_stream()
+{
+	gboolean	suspend_rq_bak = env->suspend_rq;
+
+	env->suspend_rq = TRUE;
+	fseek(resrc->fp, 0, SEEK_SET);
+	env->stream_fully_read = FALSE;
+	env->compute_rq = TRUE;
+	env->suspend_rq = suspend_rq_bak;
+}
+
 #ifdef G_OS_WIN32
 /* This is meant to be used with the new GTK/GLib-win32 runtime. */
 static int init_win32_mmtimer()
@@ -1320,8 +1342,9 @@ static gint swap_win32_logfiles()
 }
 #endif
 
+/* TODO: is this still needed ? */
 /* Question at program start-up about new feed list format conversion:
- * if version == 0.6.2 and feed list exists and feed list backup doesn't
+ * if version >= 0.6.2 and feed list exists and feed list backup doesn't
  * exist, create backup and convert to new format. */
 #define URL_LIST_BAK_FILE	URL_LIST_FILE"-bak"
 static void test_convert_local_feed_list()
@@ -1330,10 +1353,10 @@ static void test_convert_local_feed_list()
 	char	*str;
 	size_t	str_size = 8 * 1024;
 
-	if (strncmp(APP_VERSION_NUMBER, "0.6.2", 5) == 0)
+	if (strncmp(APP_VERSION_NUMBER, "0.6.2", 5) >= 0)
 		if (g_file_test(get_datafile_full_name_from_name(URL_LIST_FILE), G_FILE_TEST_EXISTS) &&\
 				!g_file_test(get_datafile_full_name_from_name(URL_LIST_BAK_FILE), G_FILE_TEST_EXISTS))
-			if (question_win(APP_NAME"-"APP_VERSION_NUMBER" uses a new feed list format internally.\n"
+			if (question_win(APP_NAME" version 0.6.2 or later uses a new feed list format internally.\n"
 					"Do you wish your local feed list to be checked and eventually converted ?\n"
 					"(Doing this ONCE is strongly RECOMMENDED.)") == YES) {
 				fp1 = open_new_datafile_with_name(URL_LIST_FILE, "rb");
