@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2013
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -54,11 +54,11 @@ void import_params()
 						while ((c = fgetc(fp1)) != (int)EOF)
 							fputc((int)c, fp2);
 						fclose(fp2);
-						/* ????
-						modify_params2();*/
-
+						get_config_file_options(get_params());
 						current_feed();
 						get_ticker_env()->reload_rq = TRUE;
+						/* ????
+						modify_params2();*/
 					} else
 						warning(FALSE, 4, "Can't save Preferences to file ",
 							file_name, ": ", strerror(errno));
@@ -208,19 +208,19 @@ void online_help()
  * Max number of strings = N_STR_MAX, max string length = STR_MAXLEN.
  * Outstanding stuff (strings and chars) will be ignored.
  */
+#define N_STR_MAX	8
+#define STR_MAXLEN	FILE_NAME_MAXLEN
+
 int big_error(int big_error_code, int n_str, ...)
 {
-#define N_STR_MAX	8
-#define STR_MAXLEN	128
-
-	char		error_str[32 + 32 + (N_STR_MAX * STR_MAXLEN) + 32 + 1];
+	char		error_str[64 + 32 + (N_STR_MAX * STR_MAXLEN) + 32 + 1];
 	va_list	str;
 	int		i;
 
 	get_ticker_env()->suspend_rq = TRUE;
 
 	error_str[0] = '\0';
-	str_n_cpy(error_str, "CRITICAL ERROR: ", 32);
+	str_n_cpy(error_str, "\nOuch !!  Something went wrong...\n\nCritical error in ", 64);
 	if (big_error_code > LIBETM_LASTERRORCODE)
 		str_n_cat(error_str, APP_NAME": ", 32);
 	n_str = MIN(n_str, N_STR_MAX);
@@ -249,9 +249,6 @@ int big_error(int big_error_code, int n_str, ...)
  * otherwise, will block until an appropriate keyboard/mouse action happens. */
 void warning(gboolean wait, int n_str, ...)
 {
-#define N_STR_MAX	8
-#define STR_MAXLEN	128
-
 	char		warning_str[N_STR_MAX * STR_MAXLEN + 1];
 	va_list	str;
 	int		i;
