@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2013
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 
 #include "tickr.h"
 
-#define OPML_FEED_RANK		APP_CMD"FeedRank"	/* NEW VERSION */
+#define OPML_FEED_RANK		APP_CMD"FeedRank"
 
 static char	*opml_str_global;
 static char	tmp_url[FILE_NAME_MAXLEN + 1], tmp_str[256];
@@ -185,7 +185,7 @@ int parse_opml_xml_file(const char *file_name)
 
 /*
  * Entry format in url list file:
- *	['*' (selected) or '-' (unselected) + (NEW VERSION) "000" (3 chars rank) + url [+ '>' + title] + '\n']
+ *	['*' (selected) or '-' (unselected) + "000" (3 chars rank) + url [+ '>' + title] + '\n']
  *
  * Entry max length = FILE_NAME_MAXLEN
  * See also:	(UN)SELECTED_URL_CHAR/STR and TITLE_TAG_CHAR/STR in tickr.h
@@ -204,13 +204,13 @@ void get_opml_selected_element(xmlNode *some_node, const char *selected_element,
 			/* Need to get attribute name and value,
 			 * then use only those whose value = "rss" for name = "type",
 			 * then get value for name = "xmlUrl" -> rss feed url,
-			 * (NEW VERSION) also eventually get value for (NOT STANDARD) name = OPML_FEED_RANK. */
+			 * also eventually get value for (NOT STANDARD) name = OPML_FEED_RANK. */
 			if ((str1 = xmlGetProp(cur_node, (xmlChar *)selected_attribute)) != NULL) {
 				if (xmlStrcmp(str1, (xmlChar *)"rss") == 0) {
 					if ((str2 = xmlGetProp(cur_node, (xmlChar *)"xmlUrl")) != NULL) {
 						/* First, we add one UNSELECTED_URL_CHAR, */
 						opml_str_global = l_str_cat(opml_str_global, UNSELECTED_URL_STR);
-						/* (NEW VERSION) then FLIST_RANK_STR_LEN chars, */
+						/* then FLIST_RANK_STR_LEN chars, */
 						if ((str3 = xmlGetProp(cur_node, (xmlChar *)OPML_FEED_RANK)) != NULL) {
 							snprintf(feed_rank, FLIST_RANK_STR_LEN + 1, FLIST_RANK_FORMAT, atoi((char *)str3));
 							xmlFree(str3);
@@ -236,6 +236,9 @@ void get_opml_selected_element(xmlNode *some_node, const char *selected_element,
 						inc_feed_counter();
 						snprintf(tmp_str, 256, "%d feed%s imported so far, please wait...",
 							*get_feed_counter(), *get_feed_counter() <= 1 ? "" : "s");
+						/*snprintf(tmp_str, 256, "%d feed%s imported so far, please wait... \n%s",
+							*get_feed_counter(), *get_feed_counter() <= 1 ? "" : "s",
+							unesc_str);*/
 						win_with_progress_bar(WIN_WITH_PROGRESS_BAR_PULSE, tmp_str);
 						g_free(unesc_str);
 						xmlFree(str2);
@@ -278,7 +281,7 @@ char *create_opml_str_from_feed_list_node(FList *node)
 		"  </head>\n"
 		"  <body>\n";
 	char 	*opml_item =
-		"    <outline title=\"%s\" type=\"rss\" xmlUrl=\"%s\" "OPML_FEED_RANK"=\"%s\"/>\n";	/* NEW VERSION */
+		"    <outline title=\"%s\" type=\"rss\" xmlUrl=\"%s\" "OPML_FEED_RANK"=\"%s\"/>\n";
 		/*"    <outline title=\"%s\" type=\"rss\" xmlUrl=\"%s\"/>\n";*/
 	char 	*opml_footer =
 		"  </body>\n"
@@ -295,7 +298,7 @@ char *create_opml_str_from_feed_list_node(FList *node)
 		}
 		esc_str1 = g_uri_escape_string(node->title, " AÄääàçéèêÖöôÜüùà'()[]-_|{}/.,;:?!%€£$*+=", TRUE);
 		esc_str2 = g_uri_escape_string(node->url, G_URI_RESERVED_CHARS_GENERIC_DELIMITERS, TRUE);
-		snprintf(tmp, STR_SIZE, opml_item, esc_str1, esc_str2, node->rank);	/* NEW VERSION */
+		snprintf(tmp, STR_SIZE, opml_item, esc_str1, esc_str2, node->rank);
 		/*snprintf(tmp, STR_SIZE, opml_item, esc_str1, esc_str2);*/
 		g_free(esc_str1);
 		g_free(esc_str2);
