@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2013
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -100,10 +100,10 @@ void set_default_options(Params *prm)
  */
 int get_config_file_options(Params *prm)
 {
-	FILE		*conf_fp;
-	char		options_array[N_OPTION_MAX][OPTION_MAXLEN + 2];
-	char		*ptr[N_OPTION_MAX + 1];
-	int		i, j = 0;
+	FILE	*conf_fp;
+	char	options_array[N_OPTION_MAX][OPTION_MAXLEN + 2];
+	char	*ptr[N_OPTION_MAX + 1];
+	int	i, j = 0;
 
 	if ((conf_fp = g_fopen(get_datafile_full_name_from_name(CONFIG_FILE), "rb")) != NULL) {
 		/*
@@ -201,6 +201,16 @@ int get_name_value_from_option(Params *prm, const char *option)
 		fprintf(STD_ERR, "Invalid option: %s\n", option);
 		return (exit_status = OPTION_INVALID);
 	}
+	/*
+	 * NEW: All *string* values are now saved inclosed in a pair of " or '.
+	 * When read, enclosing " or ' are removed, so backward compatibility is preserved.
+	 */
+	str_n_cpy(tmp, value, OPTION_MAXLEN);
+	if ((i = strlen(tmp) >= 2) && ((tmp[0] == '\"' && tmp[i - 1] == '\"') ||
+			(tmp[0] == '\'' && tmp[i - 1] == '\''))) {
+		str_n_cpy(value, tmp + 1, OPTION_VALUE_MAXLEN);
+		value[strlen(value) - 1] = '\0';
+	}
 	/*
 	 * Check option name and get value if any
 	 */
@@ -258,18 +268,20 @@ int get_name_value_from_option(Params *prm, const char *option)
 		} else
 			prm->always_on_top = value[0];
 	} else if (strcmp(name, "wintransparency") == 0) {
-		/* Compare as integers (because less bug-prone) then set as gdouble */
+		/* Compare as integers (because less bug-prone) then set as gdouble.
+		 * Saved to / retrieved from config file as [transparency x 10]. */
 		prm->win_transparency = atoi(value);
 		if ((int)prm->win_transparency < 1) {
-			prm->win_transparency = 0.1;
 			fprintf(STD_ERR, "Invalid value: %s - will be set to 1\n", option);
+			/*prm->win_transparency = 0.1; BUG */
+			prm->win_transparency = 1.0;
 			exit_status = OPTION_VALUE_INVALID;
 		} else if ((int)prm->win_transparency > 10) {
-			prm->win_transparency = 10.0;
 			fprintf(STD_ERR, "Invalid value: %s - will be set to 10\n", option);
+			prm->win_transparency = 10.0;
 			exit_status = OPTION_VALUE_INVALID;
-		} else
-			prm->win_transparency /= 10;
+		}
+		prm->win_transparency /= 10;
 	} else if (strcmp(name, "iconintaskbar") == 0) {
 		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
 			fprintf(STD_ERR, "Invalid value: %s\n", option);
@@ -486,12 +498,16 @@ void save_to_config_file(const Params *prm)
 		split_font(prm->font_n_s, fname, fsize);
 		split_font(prm->clock_font_n_s, cfname, cfsize);
 		snprintf(tmp, 4 * 1024, "%s%s%s",
+			/*
+			 * NEW: All *string* values are now saved inclosed in a pair of " or '.
+			 * Here, we have replaced %s by \"%s\".
+			 */
 			"-delay=%d\n"
 			"-shiftsize=%d\n"
-			"-fontname=%s\n"
+			"-fontname=\"%s\"\n"
 			"-fontsize=%d\n"
-			"-fgcolor=%s\n"
-			"-bgcolor=%s\n"
+			"-fgcolor=\"%s\"\n"
+			"-bgcolor=\"%s\"\n"
 			"-win_x=%d\n"
 			"-win_y=%d\n"
 			"-win_w=%d\n"
@@ -505,41 +521,41 @@ void save_to_config_file(const Params *prm)
 			"-shadowoffset_x=%d\n"
 			"-shadowoffset_y=%d\n"
 			"-shadowfx=%d\n"
-			"-linedelimiter=%s\n",
-			"-cutlinedelimiter=%s\n"
+			"-linedelimiter=\"%s\"\n",
+			"-cutlinedelimiter=\"%s\"\n"
 			"-specialchars=%c\n"
 			"-newpgchar=%c\n"
 			"-tabchar=%c\n"
 			"-rssrefresh=%d\n"
 			"-feedtitle=%c\n"
-			"-feedtitledelimiter=%s\n"
+			"-feedtitledelimiter=\"%s\"\n"
 			"-itemtitle=%c\n"
-			"-itemtitledelimiter=%s\n"
+			"-itemtitledelimiter=\"%s\"\n"
 			"-itemdescription=%c\n"
-			"-itemdescriptiondelimiter=%s\n"
+			"-itemdescriptiondelimiter=\"%s\"\n"
 			"-nitemsperfeed=%d\n"
 			"-rmtags=%c\n"
 			"-uppercasetext=%c\n"
-			"-homefeed=%s\n"
-			"-openlinkcmd=%s\n"
-			"-openlinkargs=%s\n"
+			"-homefeed=\"%s\"\n"
+			"-openlinkcmd=\"%s\"\n"
+			"-openlinkargs=\"%s\"\n"
 			"-clock=%c\n"
-			"-clockfontname=%s\n"
+			"-clockfontname=\"%s\"\n"
 			"-clockfontsize=%d\n",
-			"-clockfgcolor=%s\n"
-			"-clockbgcolor=%s\n"
+			"-clockfgcolor=\"%s\"\n"
+			"-clockbgcolor=\"%s\"\n"
 			"-disablepopups=%c\n"
 			"-pauseonmouseover=%c\n"
 			"-disableleftclick=%c\n"
 			"-mousewheelscroll=%c\n"
 			"-enablefeedordering=%c\n"
 			"-useauth=%c\n"
-			"-user=%s\n"
+			"-user=\"%s\"\n"
 			"-useproxy=%c\n"
-			"-proxyhost=%s\n"
-			"-proxyport=%s\n"
+			"-proxyhost=\"%s\"\n"
+			"-proxyport=\"%s\"\n"
 			"-useproxyauth=%c\n"
-			"-proxyuser=%s\n"
+			"-proxyuser=\"%s\"\n"
 			);
 		fprintf(conf_fp, tmp,
 			prm->delay,
