@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2013
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -1071,9 +1071,7 @@ int modify_params(Params *prm)
 		}
 		/* We want a new pixmap so that changes will be effective... now! */
 		if (response == GTK_RESPONSE_APPLY) {	/* Force apply */
-			current_feed();
-			env->reload_rq = TRUE;	/* 'compute_rq' would skip to next pixmap if any */
-			g_timeout_add_full(G_PRIORITY_DEFAULT, 100, update_everything, NULL, NULL);
+			update_pixmap_from_opened_stream();
 			changes_have_been_applied = TRUE;
 			env->suspend_rq = FALSE;
 		} else if (response == GTK_RESPONSE_OK) {
@@ -1084,9 +1082,7 @@ int modify_params(Params *prm)
 			/* Apply and save when necessary -> OK like that ? */
 			if (memcmp((const void *)prm, (const void *)prm_bak, sizeof(Params)) != 0 || \
 					changes_have_been_applied) {
-				current_feed();
-				env->reload_rq = TRUE;
-				g_timeout_add_full(G_PRIORITY_DEFAULT, 100, update_everything, NULL, NULL);
+				update_pixmap_from_opened_stream();
 				save_to_config_file(prm);
 			}
 			break;
@@ -1095,9 +1091,7 @@ int modify_params(Params *prm)
 			if (memcmp((const void *)prm, (const void *)prm_bak, sizeof(Params)) != 0 || \
 					changes_have_been_applied) {
 				memcpy((void *)prm, (const void *)prm_bak, sizeof(Params));
-				current_feed();
-				env->reload_rq = TRUE;
-				g_timeout_add_full(G_PRIORITY_DEFAULT, 100, update_everything, NULL, NULL);
+				update_pixmap_from_opened_stream();
 			}
 			break;
 		}
